/**
 * Copyright &copy; 2015-2020 <a href="http://www.jeeplus.org/">JeePlus</a> All rights reserved.
 */
package com.jeeplus.modules.sg.information.web;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


import com.google.common.collect.Lists;
import com.jeeplus.common.utils.excel.ExportExcel;
import com.jeeplus.modules.sg.information.entity.Information;
import com.jeeplus.modules.sg.information.service.InformationService;
import com.jeeplus.modules.sg.information.utils.ImportInformation;
import com.jeeplus.modules.sg.material.service.MaterialService;
import io.swagger.models.auth.In;
import org.apache.poi.ss.usermodel.Row;
import org.h2.util.New;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.method.P;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.common.utils.excel.ImportExcel;

/**
 * 项目管理列表Controller
 * @author
 * @version
 */
@Controller
@RequestMapping(value = "${adminPath}/sg/information")
public class InformationController extends BaseController {

	@Autowired
	private InformationService informationService;
	@Autowired
	private MaterialService materialService;

	@ModelAttribute
	public Information get(@RequestParam(required=false) String id) {
		Information entity = null;
		if (StringUtils.isNotBlank(id)){
			entity = informationService.get(id);
		}
		if (entity == null){
			entity = new Information();
		}
		return entity;
	}

	/**
	 * 项目管理列表页
	 */
	//@RequiresPermissions("test:information:information:list")
	@RequestMapping(value = {"list", ""})
	public String list(Information information, Model model) {
		model.addAttribute("informationList", information);
		return "modules/sg/information/informationList";
	}

		/**
	 * 项目管理列表数据
	 */
	@ResponseBody
	//@RequiresPermissions("test:onetomany:dialog:testDataMain1:list")
	@RequestMapping(value = "data")
	public Map<String, Object> data(Information information, HttpServletRequest request, HttpServletResponse response, Model model) {
		Page<Information> page = informationService.findPage(new Page<Information>(request, response), information);
		return getBootstrapData(page);
	}


	@RequestMapping(value = "form")
	public String form(Information information, Model model) {
		model.addAttribute("Information", information);
		return "modules/sg/information/informationForm";
	}




	/**
	 * 导入欠供物资Excel数据
	 */
	//@RequiresPermissions("test:onetomany:dialog:information:import")
	@ResponseBody
    @RequestMapping(value = "import")
   	public AjaxJson importFile(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {

			StringBuilder failureMsg = new StringBuilder();
			StringBuilder failInformation = new StringBuilder();
			ImportExcel ei = new ImportExcel(file, 1, 0);
//			List<Information> list = ei.getDataList(Information.class);
			int lastDataRowNum = ei.getLastDataRowNum();
			Map<String, Object> information = ImportInformation.importmation(ei, lastDataRowNum);
			int failureNum = Integer.parseInt(information.get("failureNum").toString());
			int successNum = Integer.parseInt(information.get("successNum").toString());
			List<Information> informationList= (List<Information>)information.get("importmation");
			if (failureNum>0){
				failureMsg.insert(0, "，失败 "+failureNum+" 项目管理记录。");
			}
			if (informationList != null) {
				if (informationList.size() >0) {
					for (Information in :informationList) {
						failInformation.append(in.getProjectName()+";");
					}
					failInformation.append("以上物料因出库数量与数据库中不一致未能插入");
				}
			}
			j.setMsg( "已成功导入 "+successNum+" 项目管理记录"+failureMsg+failInformation);
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入项目管理信息失败！失败信息："+e.getMessage());
		}
		return j;
    }

	/**
	 *	导入综合信息Excel数据
	 * */
	@ResponseBody
	@RequestMapping(value = "importCom")
	public AjaxJson importFileCom(@RequestParam("file")MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
		AjaxJson j = new AjaxJson();
		try {
			StringBuilder failureMsg = new StringBuilder();
			ImportExcel ei = new ImportExcel(file, 1, 0);
			int lastDataRowNum = ei.getLastDataRowNum();
			Map<String, Integer> importCom = ImportInformation.importCom(ei, lastDataRowNum);
			int failureNum = importCom.get("failureNum");
			int successNum = importCom.get("successNum");
			if (failureNum>0){
				failureMsg.insert(0, "，失败 "+failureNum+" 项目管理记录。");
			}
			j.setMsg( "已成功导入 "+successNum+" 项目管理记录"+failureMsg);
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg("导入项审定日期失败！失败信息："+e.getMessage());
		}
		return j;
	}

	/**
	 * 批量导入模板
	 * */
	@ResponseBody
//	@RequiresPermissions("test:onetomany:form:testDataMain2:import")
	@RequestMapping(value = "import/template")
	public AjaxJson importFileTemplate(HttpServletResponse response) {
		AjaxJson j = new AjaxJson();
		try {
			String fileName = "批量项目查询导入模板.xlsx";
			List<Information> list = Lists.newArrayList();
			new ExportExcel("", Information.class, 1).setDataList(list).write(response, fileName).dispose();
			return null;
		} catch (Exception e) {
			j.setSuccess(false);
			j.setMsg( "批量项目查询下载失败！失败信息："+e.getMessage());
		}
		return j;
	}


	@ResponseBody
	@RequestMapping(value = "btnSearch")
	public Map<String, Object> btnSearch(@RequestParam("file")MultipartFile file, Information information, HttpServletRequest request, HttpServletResponse response, Model model) {
		AjaxJson j = new AjaxJson();
			StringBuilder failureMsg = new StringBuilder();
			ImportExcel ei = null;
			try {
				ei = new ImportExcel(file, 1, 0);
			}catch (Exception e) {
				j.setSuccess(false);
				j.setMsg("导入项审定日期失败！失败信息："+e.getMessage());
			}
			int lastDataRowNum = ei.getLastDataRowNum();
			List<Information> infor = new ArrayList<>();
			for (int i = 1; i < lastDataRowNum; i++) {
				Information information1 = new Information();
				Row row = ei.getRow(i);
				Object projectId = ei.getCellValue(row, 0);
				Object projectName = ei.getCellValue(row, 1);
				information1.setProjectId(projectId.toString());
				information1.setProjectName(projectName.toString());
				infor.add(information1);
			}
			List<Information> listBy = informationService.findListBy(infor);
			String listCount = String.valueOf(listBy.size());
			long l = Long.parseLong(listCount);
		Page<Information> page = new Page(1, listBy.size(), l, listBy);
		List<Information> list = page.getList();
		long count = page.getCount();
		return getBootstrapData(page);
		}

}


